======
sourCy
======


.. image:: https://img.shields.io/pypi/v/sourcy.svg
        :target: https://pypi.python.org/pypi/sourcy

.. image:: https://img.shields.io/travis/SasCezar/sourcy.svg
        :target: https://travis-ci.com/SasCezar/sourcy

.. image:: https://readthedocs.org/projects/sourcy/badge/?version=latest
        :target: https://sourcy.readthedocs.io/en/latest/?badge=latest
        :alt: Documentation Status


A library for NLP like preprocessing for source code in different programming languages.
The architecture follows the one of `spaCy`_.


* Free software: GNU General Public License v3
* Documentation: https://sourcy.readthedocs.io.


Features
--------

* **Grammar based parsing**
* **Multilanguage Support**

Credits
-------

This package was created with Cookiecutter_ and the `audreyr/cookiecutter-pypackage`_ project template.

.. _Cookiecutter: https://github.com/audreyr/cookiecutter
.. _`audreyr/cookiecutter-pypackage`: https://github.com/audreyr/cookiecutter-pypackage
.. _`spaCy`: https://github.com/explosion/spaCy